package PDL::GSL;

use strict;
use warnings;

our $VERSION = '2.103';

=head1 NAME

PDL::GSL - PDL interface to the GNU Scientific Library

=head1 DESCRIPTION

This is an interface to the GNU Scientific Library. It contains the
following packages:

=over

=item L<PDL::GSL::CDF>

=item L<PDL::GSL::DIFF>

=item L<PDL::GSL::INTEG>

=item L<PDL::GSL::INTERP>

=item L<PDL::GSL::LINALG>

=item L<PDL::GSL::MROOT>

=item L<PDL::GSL::RNG>

=item L<PDL::GSL::SF>

=item L<PDL::Stats::Distr>

=back

=cut

1;
